species.data package
====================

Submodules
----------

species.data.ames\_cond module
------------------------------

.. automodule:: species.data.ames_cond
    :members:
    :undoc-members:
    :show-inheritance:

species.data.ames\_dusty module
-------------------------------

.. automodule:: species.data.ames_dusty
    :members:
    :undoc-members:
    :show-inheritance:

species.data.btnextgen module
-----------------------------

.. automodule:: species.data.btnextgen
    :members:
    :undoc-members:
    :show-inheritance:

species.data.btsettl module
---------------------------

.. automodule:: species.data.btsettl
    :members:
    :undoc-members:
    :show-inheritance:

species.data.companions module
------------------------------

.. automodule:: species.data.companions
    :members:
    :undoc-members:
    :show-inheritance:

species.data.database module
----------------------------

.. automodule:: species.data.database
    :members:
    :undoc-members:
    :show-inheritance:

species.data.drift\_phoenix module
----------------------------------

.. automodule:: species.data.drift_phoenix
    :members:
    :undoc-members:
    :show-inheritance:

species.data.filters module
---------------------------

.. automodule:: species.data.filters
    :members:
    :undoc-members:
    :show-inheritance:

species.data.irtf module
------------------------

.. automodule:: species.data.irtf
    :members:
    :undoc-members:
    :show-inheritance:

species.data.isochrones module
------------------------------

.. automodule:: species.data.isochrones
    :members:
    :undoc-members:
    :show-inheritance:

species.data.leggett module
---------------------------

.. automodule:: species.data.leggett
    :members:
    :undoc-members:
    :show-inheritance:

species.data.petitcode module
-----------------------------

.. automodule:: species.data.petitcode
    :members:
    :undoc-members:
    :show-inheritance:

species.data.queries module
---------------------------

.. automodule:: species.data.queries
    :members:
    :undoc-members:
    :show-inheritance:

species.data.spex module
------------------------

.. automodule:: species.data.spex
    :members:
    :undoc-members:
    :show-inheritance:

species.data.vega module
------------------------

.. automodule:: species.data.vega
    :members:
    :undoc-members:
    :show-inheritance:

species.data.vlm\_plx module
----------------------------

.. automodule:: species.data.vlm_plx
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: species.data
    :members:
    :undoc-members:
    :show-inheritance:
